==> beast-payment-api-1.3.3-20201218.054318-5-sources.jar: com/thebeastshop/payment/vo/wxcard/PWxCardBonus.java <==
package com.thebeastshop.payment.vo.wxcard;

import com.alibaba.fastjson.annotation.JSONField;

public class PWxCardBonus {

    @JSONField(name = "init_bonus")
    private int initBonus;

    @JSONField(name = "bonus_value_word")
    private String bonusValueWord;

    @JSONField(name = "bonus_cost_word")
    private String bonusCostWord;

    @JSONField(name = "bonus_jump_word")
    private String bonusJumpWord;

    @JSONField(name = "bonus_jump_appid")
    private String bonusJumpAppid;

    @JSONField(name = "bonus_jump_path")
    private String bonusJumpPath;

    @JSONField(name = "bonus_support_appid")
    private String bonusSupportAppid;

    @JSONField(name = "bonus_support_path")
    private String bonusSupportPath;

    public int getInitBonus() {
        return initBonus;
    }

    public void setInitBonus(int initBonus) {
        this.initBonus = initBonus;
    }

    public String getBonusValueWord() {
        return bonusValueWord;
    }

    public void setBonusValueWord(String bonusValueWord) {
        this.bonusValueWord = bonusValueWord;
    }

    public String getBonusCostWord() {
        return bonusCostWord;
    }

    public void setBonusCostWord(String bonusCostWord) {
        this.bonusCostWord = bonusCostWord;
    }

    public String getBonusJumpWord() {
        return bonusJumpWord;
    }

    public void setBonusJumpWord(String bonusJumpWord) {
        this.bonusJumpWord = bonusJumpWord;
    }

    public String getBonusJumpAppid() {
        return bonusJumpAppid;
    }

    public void setBonusJumpAppid(String bonusJumpAppid) {
        this.bonusJumpAppid = bonusJumpAppid;
    }

    public String getBonusJumpPath() {
        return bonusJumpPath;
    }

    public void setBonusJumpPath(String bonusJumpPath) {
        this.bonusJumpPath = bonusJumpPath;
    }

    public String getBonusSupportAppid() {
        return bonusSupportAppid;
    }

    public void setBonusSupportAppid(String bonusSupportAppid) {
        this.bonusSupportAppid = bonusSupportAppid;
    }

    public String getBonusSupportPath() {
        return bonusSupportPath;
    }

    public void setBonusSupportPath(String bonusSupportPath) {
        this.bonusSupportPath = bonusSupportPath;
    }
}

==> beast-payment-api-1.3.17-sources.jar: com/thebeastshop/payment/vo/wxcard/PWxCardBonus.java <==
package com.thebeastshop.payment.vo.wxcard;

import com.alibaba.fastjson.annotation.JSONField;
import com.thebeastshop.common.BaseDO;

public class PWxCardBonus extends BaseDO {

    @JSONField(name = "init_bonus")
    private int initBonus;

    @JSONField(name = "bonus_value_word")
    private String bonusValueWord;

    @JSONField(name = "bonus_cost_word")
    private String bonusCostWord;

    @JSONField(name = "bonus_jump_word")
    private String bonusJumpWord;

    @JSONField(name = "bonus_jump_appid")
    private String bonusJumpAppid;

    @JSONField(name = "bonus_jump_path")
    private String bonusJumpPath;

    @JSONField(name = "bonus_support_appid")
    private String bonusSupportAppid;

    @JSONField(name = "bonus_support_path")
    private String bonusSupportPath;

    public int getInitBonus() {
        return initBonus;
    }

    public void setInitBonus(int initBonus) {
        this.initBonus = initBonus;
    }

    public String getBonusValueWord() {
        return bonusValueWord;
    }

    public void setBonusValueWord(String bonusValueWord) {
        this.bonusValueWord = bonusValueWord;
    }

    public String getBonusCostWord() {
        return bonusCostWord;
    }

    public void setBonusCostWord(String bonusCostWord) {
        this.bonusCostWord = bonusCostWord;
    }

    public String getBonusJumpWord() {
        return bonusJumpWord;
    }

    public void setBonusJumpWord(String bonusJumpWord) {
        this.bonusJumpWord = bonusJumpWord;
    }

    public String getBonusJumpAppid() {
        return bonusJumpAppid;
    }

    public void setBonusJumpAppid(String bonusJumpAppid) {
        this.bonusJumpAppid = bonusJumpAppid;
    }

    public String getBonusJumpPath() {
        return bonusJumpPath;
    }

    public void setBonusJumpPath(String bonusJumpPath) {
        this.bonusJumpPath = bonusJumpPath;
    }

    public String getBonusSupportAppid() {
        return bonusSupportAppid;
    }

    public void setBonusSupportAppid(String bonusSupportAppid) {
        this.bonusSupportAppid = bonusSupportAppid;
    }

    public String getBonusSupportPath() {
        return bonusSupportPath;
    }

    public void setBonusSupportPath(String bonusSupportPath) {
        this.bonusSupportPath = bonusSupportPath;
    }
}
